package com.spiderlee.spider_lee

import android.content.Context
import android.content.Intent
import android.util.Log
import com.spiderlee.spider_lee.SpiderLeePlugin.Companion.Spider_PLUGIN_TAG
import org.jitsi.meet.sdk.JitsiMeetActivity
import org.jitsi.meet.sdk.JitsiMeetConferenceOptions
import android.content.res.Configuration

/**
 * Activity extending JitsiMeetActivity in order to override the conference events
 */
class SpiderLeePluginActivity: JitsiMeetActivity() {
    companion object {
        @JvmStatic
        fun launchActivity(context: Context?,
                           options: JitsiMeetConferenceOptions) {
            var intent = Intent(context, SpiderLeePluginActivity::class.java).apply {
                action = "org.jitsi.meet.CONFERENCE"
                putExtra("JitsiMeetConferenceOptions", options)
            }
            context?.startActivity(intent)
        }
    }

    var onStopCalled: Boolean = false;

    override fun onPictureInPictureModeChanged( isInPictureInPictureMode: Boolean, newConfig: Configuration?)
    {
        super.onPictureInPictureModeChanged(isInPictureInPictureMode, newConfig)

        if (isInPictureInPictureMode == false && onStopCalled)
        {
            // Picture-in-Picture mode has been closed, we can (should !) end the call
            getJitsiView().leave()
        }
    }

    override fun onStop()
    {
        super.onStop()
        onStopCalled = true;
    }

    override fun onResume()
    {
        super.onResume()
        onStopCalled = false;
    }

    override fun onConferenceWillJoin(data: MutableMap<String, Any>?) {
        Log.d(Spider_PLUGIN_TAG, String.format("SpiderLeePluginActivity.onConferenceWillJoin: %s", data))
        SpiderLeeEventStreamHandler.instance.onConferenceWillJoin(data)
        super.onConferenceWillJoin(data)
    }

    override fun onConferenceJoined(data: MutableMap<String, Any>?) {
        Log.d(Spider_PLUGIN_TAG, String.format("SpiderLeePluginActivity.onConferenceJoined: %s", data))
        SpiderLeeEventStreamHandler.instance.onConferenceJoined(data)
        super.onConferenceJoined(data)
    }

    override fun onConferenceTerminated(data: MutableMap<String, Any>?) {

        Log.d(Spider_PLUGIN_TAG, String.format("SpiderLeePluginActivity.onConferenceTerminated: %s", data))
        SpiderLeeEventStreamHandler.instance.onConferenceTerminated(data)
        super.onConferenceTerminated(data)
    }
}